API Client Daylisoft
=======================


Paquete API Client de Daylisoft

----

La aplicación ha sido desarrollada para permitir a los contribuyentes la generación de comprobantes electrónicos basándose en el esquema de emisión electrónica Offline del Servicio de Rentas Internas (SRI), lo cual ayudará a realizar el proceso de emisión de dichos comprobantes.

Permite guardar los archivos XML: generados, firmados y autorizados

Para mayor información, visitar `www.daylisoft.com.ec
<https://daylisoft.com.ec/>`_.
